summaryrefslogtreecommitdiffstats
path: root/Core/User/InMemoryUserProvider.php
diff options
context:
space:
mode:
Diffstat (limited to 'Core/User/InMemoryUserProvider.php')
-rw-r--r--Core/User/InMemoryUserProvider.php16
1 files changed, 8 insertions, 8 deletions
diff --git a/Core/User/InMemoryUserProvider.php b/Core/User/InMemoryUserProvider.php
index 7d4d1cc..26b4080 100644
--- a/Core/User/InMemoryUserProvider.php
+++ b/Core/User/InMemoryUserProvider.php
@@ -12,7 +12,7 @@
namespace Symfony\Component\Security\Core\User;
use Symfony\Component\Security\Core\Exception\UsernameNotFoundException;
-use Symfony\Component\Security\Core\Exception\UnsupportedAccountException;
+use Symfony\Component\Security\Core\Exception\UnsupportedUserException;
/**
* InMemoryUserProvider is a simple non persistent user provider.
@@ -24,7 +24,7 @@ use Symfony\Component\Security\Core\Exception\UnsupportedAccountException;
*/
class InMemoryUserProvider implements UserProviderInterface
{
- protected $users;
+ private $users;
/**
* Constructor.
@@ -50,9 +50,9 @@ class InMemoryUserProvider implements UserProviderInterface
/**
* Adds a new User to the provider.
*
* @param AccountInterface $user A AccountInterface instance
*/
- public function createUser(AccountInterface $user)
+ public function createUser(UserInterface $user)
{
if (isset($this->users[strtolower($user->getUsername())])) {
throw new \LogicException('Another user with the same username already exist.');
@@ -79,13 +79,13 @@ class InMemoryUserProvider implements UserProviderInterface
/**
* {@inheritDoc}
*/
- public function loadUserByAccount(AccountInterface $account)
+ public function loadUser(UserInterface $user)
{
- if (!$account instanceof User) {
- throw new UnsupportedAccountException(sprintf('Instances of "%s" are not supported.', get_class($account)));
+ if (!$user instanceof User) {
+ throw new UnsupportedUserException(sprintf('Instances of "%s" are not supported.', get_class($user)));
}
- return $this->loadUserByUsername((string) $account);
+ return $this->loadUserByUsername($user->getUsername());
}
/**
@@ -50,9 +50,9 @@ class InMemoryUserProvider implements UserProviderInterface
* Adds a new User to the provider.
*
- * @param AccountInterface $user A AccountInterface instance
+ * @param UserInterface $user A UserInterface instance
*/